<?php
// catalog/controller/extension/ajax/callbackform.php

/**
 * @link https://www.wisereport.ru
 * @author Paul aka root4root <root4root@gmail.com>
 * @license http://www.gnu.org/copyleft/lesser.html GNU Lesser General Public License
 * @note This program is distributed in the hope that it will be useful - WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.
 */

class ControllerExtensionAjaxCallbackform extends Controller
{
    public function ajaxSend()
    {
        if ($this->request->server['REQUEST_METHOD'] !== 'POST'){
            return false;
        }

        $parse = parse_url($this->config->get('config_url'));
        $domain = $parse['host'];

        $this->response->addHeader('Content-Type: application/json');

        if (!isset($this->request->server['HTTP_X_REQUESTED_WITH']) &&
            strtolower($this->request->server['HTTP_X_REQUESTED_WITH']) != 'xmlhttprequest'
        ) {
            $output = json_encode([
                'type'=>'error',
                'text' => 'Sorry Request must be Ajax POST',
            ]);

            $this->response->setOutput($output);
            return false;
        }

        $user_name = $this->request->post['user_name'];
        $phone_number = $this->request->post['phone_number'];
        $message = $this->request->post['msg'];

        if (strlen($user_name) < 4) {

            $output = json_encode([
                'type'=>'error',
                'text' => 'Слишком короткое имя',
            ]);

            $this->response->setOutput($output);
            return false;
        }

        if (!filter_var($phone_number, FILTER_SANITIZE_NUMBER_FLOAT)) {
            $output = json_encode([
                'type'=>'error',
                'text' => 'Некорректный телефон',
            ]);

            $this->response->setOutput($output);
            return false;
        }

        $mailProtocol = $this->config->get('config_mail_engine');

        $mail = new Mail($mailProtocol);

        if (!empty($this->config->get('config_mail_parameter'))) {
            $mail->parameter = $this->config->get('config_mail_parameter');
        } else {
            $mail->parameter = '-finfo@' . $domain;
        }

        $mail->smtp_hostname = $this->config->get('config_mail_smtp_hostname');
        $mail->smtp_username = $this->config->get('config_mail_smtp_username');
        $mail->smtp_password = $this->config->get('config_mail_smtp_password');
        $mail->smtp_port = $this->config->get('config_mail_smtp_port');
        $mail->smtp_timeout = $this->config->get('config_mail_smtp_timeout');
        $mail->setTo($this->config->get('config_email'));

        if ($mailProtocol !== 'mail') {
            $mail->setFrom($mail->smtp_username);
        } else {
            $mail->setFrom('info@' . $domain);
        }

        $mail->setSender($domain);
        $mail->setSubject('Сообщение с сайта ' . $domain);

        $mail->setText('Имя отправителя: '
                       . $user_name
                       . "\r\nТелефон: "
                       . $phone_number
                       . "\r\nСообщение: "
                       . $message);
        
        $mail->setHtml('<b>Имя отправителя :</b>' . $user_name . '<br>' 
                     . '<b>Телефон :</b>' . $phone_number . '<br>' 
                     . '<b>Сообщение: </b>' . $message);

        $mail->send();

        $this->response->setOutput(json_encode([
            'type'=>'message',
            'text' => 'Ваше сообщение отправлено!',
        ]));
    }
}